## 深圳市场每日交易概况

接口：sz_daily_info

描述：获取深圳市场每日交易概况

限量：单次最大2000，可循环获取，总量不限制

权限：用户积2000积分可调取， 频次有限制，积分越高每分钟调取频次越高，5000积分以上频次相对较高，积分获取方法请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| ts_code | str | N | 板块代码 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

ts_code主要包括：

| 板块代码（TS_CODE） | 板块说明 | 数据开始日期 |
| --- | --- | --- |
| 股票 | 深圳市场股票总和 | 20080102 |
| 主板A股 | 深圳主板A股情况 | 20080102 |
| 主板B股 | 深圳主板B股情况 | 20080102 |
| 创业板A股 | 深圳创业板情况 | 20080102 |
| 基金 | 深圳市场基金总和 | 20080102 |
| ETF | 深圳ETF交易情况 | 20080102 |
| LOF | 深圳LOF交易情况 | 20080102 |
| 封闭式基金 | 深圳封闭式基金交易情况 | 20080102 |
| 基础设施基金 | 深圳RETIS基金交易情况 | 20210621 |
| 债券 | 深圳债券市场总和 | 20080102 |
| 债券现券 | 深圳现券交易情况 | 20080102 |
| 债券回购 | 深圳债券回购交易情况 | 20080102 |
| ABS | 深圳ABS交易情况 | 20080102 |
| 期权 | 深圳期权总和 | 20080102 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y |  |
| ts_code | str | Y | 市场类型 |
| count | int | Y | 股票个数 |
| amount | float | Y | 成交金额 |
| vol | None | Y | 成交量 |
| total_share | float | Y | 总股本 |
| total_mv | float | Y | 总市值 |
| float_share | float | Y | 流通股票 |
| float_mv | float | Y | 流通市值 |

接口示例

```python
#获取深圳市场20200320交易数据
df = pro.sz_daily_info(trade_date='20200320')

#获取深圳市场交易情况
df = pro.sz_daily_info(trade_date='20200320', ts_code='股票')
```

数据示例

```python
trade_date ts_code  count           amount          vol            total_share           total_mv                       float_share           float_mv
0    20200320     ABS    541     504804930.72      4843368     5004918501.00    472061975980.53     5004918501.00    472061975980.53
```